package cat.pepweb.pep.jdbc;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;


import cat.pepweb.pep.beans.Trajectes;
import cat.pepweb.pep.utilitats.GestioDates;


public class OperacionsTrajectesUsuari extends Connexio{

	private static final String CREAR_REGISTRE="INSERT INTO trajectepublicat (origen, destinacio, data," +
			" hora, minut, model_cotxe, places, preu, mida_equipatge, e_mail, permes_fumar, radio_mp3," +
			"distancia, temps) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?);"; 
	private static final String ACTUALITZAR_REGISTRE="UPDATE trajectepublicat SET id=?, origen=?," +
			" destinacio=?, data=?, hora=?, minut=?, model_cotxe=?, places=?, preu=?, mida_equipatge=?," +
			"e_mail=?, permes_fumar=?, radio_mp3=?, distancia=?, temps=? WHERE id=?;";  
	private static final String LLISTAR_REGISTRES="SELECT * FROM trajectepublicat WHERE e_mail=?;";
	private static final String LLEGIR_REGISTRE	="SELECT * FROM trajectepublicat WHERE id=?;";
	private static final String ESBORRAR_REGISTRE="DELETE FROM trajectepublicat WHERE id=?;";
	private static final String LLISTAR_TOTS_ELS_REGISTRES="SELECT * FROM trajectepublicat WHERE data=?;";
	private static final String LLISTAR_TOTS_ELS_REGISTRES_2="SELECT * FROM trajectepublicat WHERE data >=?;";

	private PreparedStatement ps=null;
	GestioDates dataSql = new GestioDates();

	/**
	 * Mtode que dona d'alta a la base de dades un nou trajecte publicat per un usuari.
	 * @param trajecte
	 * @return
	 */
	public int crearTrajecte(Trajectes trajecte) {


		//Convertim StringDate a java.sql.Date

		java.sql.Date data = dataSql.retornaStringComSqlData(trajecte.getData());


		Connection con;
		con = obrirConnexio();
		int t = 0;
		try {

			ps = con.prepareStatement(CREAR_REGISTRE);


			ps.setString(1,trajecte.getOrigen());
			ps.setString(2,trajecte.getDestinacio());
			ps.setDate(3, data);
			ps.setInt(4, trajecte.getHora());
			ps.setInt(5, trajecte.getMinut());
			ps.setString(6,trajecte.getModel_cotxe());
			ps.setInt(7, trajecte.getPlaces());
			ps.setDouble(8, trajecte.getPreu());
			ps.setString(9, trajecte.getMida_equipatge());
			ps.setString(10, trajecte.getE_mail());
			ps.setBoolean(11, trajecte.isPermes_fumar());
			ps.setBoolean(12, trajecte.isRadio_mp3());
			ps.setInt(13, trajecte.getDistancia());
			ps.setInt(14, trajecte.getTemps());

			t = ps.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();}
		tancarConnexio();
		return t;
	}


	/**
	 * Mtode que retorna una llista amb els trajectes que un determinat usuari t publicats.
	 * @param e_mail
	 * @return
	 */
	public List<Trajectes> llistarTrajectesUsuari(String e_mail) {

		Connection con;
		con = obrirConnexio();
		Trajectes traj[] = new Trajectes[100];
		List <Trajectes> lt = new ArrayList<Trajectes>();
		int a = 0;
		try {
			ps = con.prepareStatement(LLISTAR_REGISTRES);
			ps.setString(1, e_mail);
			ResultSet rs = ps.executeQuery();
			while(rs.next()) {
				traj[a] = new Trajectes();
				//Passem la sqlDate a String amb el format dd/MM/yyyy;
				String dataString = dataSql.pasarDateAString(rs.getDate("data"));

				traj[a].setId(rs.getInt("id"));
				traj[a].setOrigen(rs.getString("origen"));
				traj[a].setDestinacio(rs.getString("destinacio"));
				traj[a].setData(dataString);
				traj[a].setHora(rs.getInt("hora"));
				traj[a].setMinut(rs.getInt("minut"));
				traj[a].setModel_cotxe(rs.getString("model_cotxe"));
				traj[a].setPlaces(rs.getInt("places"));
				traj[a].setPreu(rs.getDouble("preu"));
				traj[a].setMida_equipatge(rs.getString("mida_equipatge"));
				traj[a].setE_mail(rs.getString("e_mail"));
				traj[a].setPermes_fumar(rs.getBoolean("permes_fumar"));
				traj[a].setRadio_mp3(rs.getBoolean("radio_mp3"));
				traj[a].setDistancia(rs.getInt("distancia"));
				traj[a].setTemps(rs.getInt("temps"));

				lt.add(traj[a]);
				a = a+1;
			}
		}
		catch (SQLException e) {
			e.printStackTrace();
		}
		tancarConnexio();
		return lt;
	}

	/**
	 * Mtode que permet esborrar un trajecte publicat per un usuari.
	 * @param idTrajecte
	 * @return
	 */
	public int esborrarTrajecte(int idTrajecte) {

		Connection con;
		con = obrirConnexio();
		int t = 0;

		try {

			ps = con.prepareStatement(ESBORRAR_REGISTRE);
			ps.setInt(1, idTrajecte);
			t = ps.executeUpdate();	
		}catch (SQLException e){
			e.printStackTrace();}
		tancarConnexio();

		return t;
	}

	/**
	 * Aquest mtode ens permet actualitzar un trajecte d'usuari modificat.
	 * @param trajecte
	 * @return
	 */
	public int actualitzarTrajecte(Trajectes trajecte) {

		//Convertim StringDate a java.sql.Date

		java.sql.Date data = dataSql.retornaStringComSqlData(trajecte.getData());


		Connection con;
		con = obrirConnexio();
		int t = 0;
		try {

			ps = con.prepareStatement(ACTUALITZAR_REGISTRE);


			ps.setInt(1,trajecte.getId());
			ps.setString(2,trajecte.getOrigen());
			ps.setString(3,trajecte.getDestinacio());
			ps.setDate(4, data);
			ps.setInt(5, trajecte.getHora());
			ps.setInt(6, trajecte.getMinut());
			ps.setString(7,trajecte.getModel_cotxe());
			ps.setInt(8, trajecte.getPlaces());
			ps.setDouble(9, trajecte.getPreu());
			ps.setString(10, trajecte.getMida_equipatge());
			ps.setString(11, trajecte.getE_mail());
			ps.setBoolean(12, trajecte.isPermes_fumar());
			ps.setBoolean(13, trajecte.isRadio_mp3());
			ps.setInt(14, trajecte.getDistancia());
			ps.setInt(15, trajecte.getTemps());
			ps.setInt(16, trajecte.getId());

			t = ps.executeUpdate();

		} catch (SQLException e) {
			e.printStackTrace();}
		tancarConnexio();
		return t;
	}

	/**
	 * Mtode que retorna un trajecte segons l'id que un determinat 
	 * usuari t publicat.
	 * @param e_mail
	 * @return
	 */
	public Trajectes trobarTrajecte(int id) {

		Connection con;
		Trajectes tr = new Trajectes();
		con = obrirConnexio();
		try {
			ps = con.prepareStatement(LLEGIR_REGISTRE);
			ps.setInt(1, id);

			ResultSet rs = ps.executeQuery();
			while(rs.next()) {

				//Passem la sqlDate a String amb el format dd/MM/yyyy;
				String dataString = dataSql.pasarDateAString(rs.getDate("data"));

				tr.setId(rs.getInt("id"));
				tr.setOrigen(rs.getString("origen"));
				tr.setDestinacio(rs.getString("destinacio"));
				tr.setData(dataString);
				tr.setHora(rs.getInt("hora"));
				tr.setMinut(rs.getInt("minut"));
				tr.setModel_cotxe(rs.getString("model_cotxe"));
				tr.setPlaces(rs.getInt("places"));
				tr.setPreu(rs.getDouble("preu"));
				tr.setMida_equipatge(rs.getString("mida_equipatge"));
				tr.setE_mail(rs.getString("e_mail"));
				tr.setPermes_fumar(rs.getBoolean("permes_fumar"));
				tr.setRadio_mp3(rs.getBoolean("radio_mp3"));
				tr.setDistancia(rs.getInt("distancia"));
				tr.setTemps(rs.getInt("temps"));

			}
		}
		catch (SQLException e) {
			e.printStackTrace();
		}
		tancarConnexio();
		return tr;
	}

	/**
	 * Mtode que retorna una llista amb tots els trajectes publicats en una data.
	 * @param e_mail
	 * @return
	 */
	public List<Trajectes> llistarTrajectes(String data) {

		//Convertim StringDate a java.sql.Date

		java.sql.Date data1 = dataSql.retornaStringComSqlData(data);

		Connection con;
		con = obrirConnexio();
		Trajectes traj[] = new Trajectes[1000];
		List <Trajectes> lt = new ArrayList<Trajectes>();
		int a = 0;
		try {
			ps = con.prepareStatement(LLISTAR_TOTS_ELS_REGISTRES);
			ps.setDate(1, data1);
			ResultSet rs = ps.executeQuery();
			while(rs.next()) {
				traj[a] = new Trajectes();
				//Passem la sqlDate a String amb el format dd/MM/yyyy;
				String dataString = dataSql.pasarDateAString(rs.getDate("data"));

				traj[a].setId(rs.getInt("id"));
				traj[a].setOrigen(rs.getString("origen"));
				traj[a].setDestinacio(rs.getString("destinacio"));
				traj[a].setData(dataString);
				traj[a].setHora(rs.getInt("hora"));
				traj[a].setMinut(rs.getInt("minut"));
				traj[a].setModel_cotxe(rs.getString("model_cotxe"));
				traj[a].setPlaces(rs.getInt("places"));
				traj[a].setPreu(rs.getDouble("preu"));
				traj[a].setMida_equipatge(rs.getString("mida_equipatge"));
				traj[a].setE_mail(rs.getString("e_mail"));
				traj[a].setPermes_fumar(rs.getBoolean("permes_fumar"));
				traj[a].setRadio_mp3(rs.getBoolean("radio_mp3"));
				traj[a].setDistancia(rs.getInt("distancia"));
				traj[a].setTemps(rs.getInt("temps"));

				lt.add(traj[a]);
				a = a+1;
			}
		}
		catch (SQLException e) {
			e.printStackTrace();
		}
		tancarConnexio();
		return lt;
	}

	/**
	 * Mtode que retorna una llista amb tots els trajectes publicats.
	 * @param e_mail
	 * @return
	 */
	public List<Trajectes> llistarTrajectes() {

		//Convertim StringDate a java.sql.Date
		
		GestioDates gd = new GestioDates();
		

		java.sql.Date data1 = gd.retornaDataActualComSqlData();

		Connection con;
		con = obrirConnexio();
		Trajectes traj[] = new Trajectes[1000];
		List <Trajectes> lt = new ArrayList<Trajectes>();
		int a = 0;
		try {
			ps = con.prepareStatement(LLISTAR_TOTS_ELS_REGISTRES_2);
			ps.setDate(1, data1);
			ResultSet rs = ps.executeQuery();
			while(rs.next()) {
				traj[a] = new Trajectes();
				//Passem la sqlDate a String amb el format dd/MM/yyyy;
				String dataString = dataSql.pasarDateAString(rs.getDate("data"));

				traj[a].setId(rs.getInt("id"));
				traj[a].setOrigen(rs.getString("origen"));
				traj[a].setDestinacio(rs.getString("destinacio"));
				traj[a].setData(dataString);
				traj[a].setHora(rs.getInt("hora"));
				traj[a].setMinut(rs.getInt("minut"));
				traj[a].setModel_cotxe(rs.getString("model_cotxe"));
				traj[a].setPlaces(rs.getInt("places"));
				traj[a].setPreu(rs.getDouble("preu"));
				traj[a].setMida_equipatge(rs.getString("mida_equipatge"));
				traj[a].setE_mail(rs.getString("e_mail"));
				traj[a].setPermes_fumar(rs.getBoolean("permes_fumar"));
				traj[a].setRadio_mp3(rs.getBoolean("radio_mp3"));
				traj[a].setDistancia(rs.getInt("distancia"));
				traj[a].setTemps(rs.getInt("temps"));

				lt.add(traj[a]);
				a = a+1;
			}
		}
		catch (SQLException e) {
			e.printStackTrace();
		}
		tancarConnexio();
		return lt;
	}


}
